@@ -1,4 +1,5 @@
 import argparse
+from .settings import MEDIA_SIZES
 
 
 def parse_args():
@@ -20,5 +21,9 @@ def parse_args():
                         help=count_help)
     parser.add_argument('-i', '--increment', action='store_true',
                         help='download only new photos since last download')
+    parser.add_argument('-e', '--exclude_replies', action='store_true',
+                        help='exclude replies')
+    parser.add_argument('-s', '--size', choices=MEDIA_SIZES,
+                        help='photo size')
     args = parser.parse_args()
     return args
